@@ -1,5 +1,5 @@
 /*-*-c++-*-
- * $Id: toplevel.cpp,v 1.13 2002/07/07 13:45:59 felfert Exp $
+ * $Id: toplevel.cpp,v 1.16 2005/08/28 22:45:07 rrt Exp $
  *
  * This file is part of plptools.
  *
@@ -30,7 +30,7 @@
 #include <qcursor.h>
 
 #include <kaction.h>
-#include <kapp.h>
+#include <kapplication.h>
 #include <klocale.h>
 #include <kwin.h>
 #include <kiconloader.h>
@@ -40,10 +40,14 @@
 
 #include <psibitmap.h>
 
+#include <iostream>
+
 #define QUIT_ITEM    50
 #define ABOUT_ITEM    51
 #define CLIPFILE "C:/System/Data/Clpboard.cbd"
 
+using namespace std;
+
 TopLevel::TopLevel()
   : KMainWindow(0)
 {
@@ -593,7 +597,7 @@ checkConnection() {
 		    KMessageBox::error(NULL, i18n(
 			"<QT>Your Psion does not support the remote clipboard "
 			"protocol.<BR/>The reason for that is usually a missing "
-			"server library on your Psion.<BR/>Make shure, that "
+			"server library on your Psion.<BR/>Make sure that "
 			"<B>C:\\System\\Libs\\clipsvr.rsy</B> exists.<BR/>"
 			"This file is part of PsiWin and usually gets copied "
 			"to your Psion when you enable CopyAnywhere in PsiWin. "
