@@ -1,5 +1,5 @@
 /*-*-c++-*-
- * $Id: toplevel.h,v 1.8 2002/07/07 13:45:59 felfert Exp $
+ * $Id: toplevel.h,v 1.9 2005/08/28 22:45:07 rrt Exp $
  *
  * This file is part of plptools.
  *
@@ -28,7 +28,7 @@
 # include <config.h>
 #endif
 
-#include <kapp.h>
+#include <kapplication.h>
 #include <kmainwindow.h>
 #include <kpopupmenu.h>
 #include <kaboutapplication.h>
