@@ -1,5 +1,5 @@
 /*-*-c++-*-
- * $Id: kpsion.cpp,v 1.21 2003/02/03 08:29:25 felfert Exp $
+ * $Id: kpsion.cpp,v 1.23 2005/08/28 22:37:14 rrt Exp $
  *
  * This file is part of plptools.
  *
@@ -55,8 +55,12 @@
 #include <bufferarray.h>
 #include <psiprocess.h>
 
+#include <iostream>
+
 #define STID_CONNECTION 1
 
+using namespace std;
+
 KPsionMainWindow::KPsionMainWindow()
     : KMainWindow() {
     setupActions();
@@ -1768,7 +1772,7 @@ killSave() {
 	    KMessageBox::error(this, i18n(
 		"<QT>Could not stop all processes.<BR/>"
 		"Please stop running programs manually on the Psion, "
-		"then klick <B>Ok</B>."));
+		"then click <B>Ok</B>."));
 	    tstart = time(0) + 5;
 	}
     }
