@@ -1,5 +1,5 @@
 /*-*-c++-*-
- * $Id: kpsionbackuplistview.cpp,v 1.7 2002/08/11 01:41:44 felfert Exp $
+ * $Id: kpsionbackuplistview.cpp,v 1.8 2005/08/28 22:37:14 rrt Exp $
  *
  * This file is part of plptools.
  *
@@ -29,7 +29,7 @@
 #include "kpsionbackuplistview.h"
 #include "kpsionconfig.h"
 
-#include <kapp.h>
+#include <kapplication.h>
 #include <klocale.h>
 #include <kconfig.h>
 #include <kiconloader.h>
