@@ -1,5 +1,5 @@
 /*-*-c++-*-
- * $Id: main.cpp,v 1.8 2003/02/03 00:29:35 felfert Exp $
+ * $Id: main.cpp,v 1.9 2005/08/28 22:37:14 rrt Exp $
  *
  * This file is part of plptools.
  *
@@ -27,7 +27,7 @@
 #include "kpsion.h"
 #include "kpsionconfig.h"
 #include "wizards.h"
-#include <kapp.h>
+#include <kapplication.h>
 #include <klocale.h>
 #include <kconfig.h>
 #include <kcmdlineargs.h>
