@@ -1,5 +1,5 @@
 /*-*-c++-*-
- * $Id: statusbarprogress.cpp,v 1.2 2002/07/07 13:30:59 felfert Exp $
+ * $Id: statusbarprogress.cpp,v 1.3 2005/08/28 22:37:14 rrt Exp $
  *
  *   Shamlessly stolen from:
  *     khexedit - Versatile hex editor
@@ -30,7 +30,7 @@
 #include <qtooltip.h>
 #include <qstyle.h>
 
-#include <kapp.h>
+#include <kapplication.h>
 #include <kglobal.h>
 #include <kglobalsettings.h>
 #include <klocale.h>
