@@ -1,5 +1,5 @@
 /*-*-c++-*-
- * $Id: Enum.cc,v 1.3 2002/07/14 06:35:33 felfert Exp $
+ * $Id: Enum.cc,v 1.4 2003/02/05 07:59:08 felfert Exp $
  *
  * This file is part of plptools.
  *
@@ -20,6 +20,10 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
  */
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "Enum.h"
 
 using namespace std;
