@@ -1,5 +1,5 @@
 /*-*-c++-*-
- * $Id: Enum.h,v 1.8 2002/07/14 19:07:04 felfert Exp $
+ * $Id: Enum.h,v 1.13 2005/08/06 12:10:18 rrt Exp $
  *
  * This file is part of plptools.
  *
@@ -27,11 +27,13 @@
 #include <config.h>
 #endif
 
-#include <plpintl.h>
-
+#include <assert.h>
 #include <map>
 #include <string>
 
+#include <plpintl.h>
+#include <assert.h>
+
 /**
  * the Base for the Enum template.
  * currently, only purpose is to provide a class type for mapping
@@ -138,7 +140,7 @@ protected:
  */
 template<typename E>
 class Enum : private EnumBase {
-private:
+public:
     struct sdata {
 	/**
 	 * The constructor of the static data part.
@@ -257,10 +259,13 @@ public:
     * XXX: throw OutOfRangeException ?
     */
     static E getValueFor(const std::string &s) {
-	return (E) staticData.stringRep.lookup(s.getCStr());
+//	return (E) staticData.stringRep.lookup(s.getCStr());
+	return (E) staticData.stringRep.lookup(s.c_str());
     }
 };
 
+template<typename E> typename Enum<E>::sdata Enum<E>::staticData;
+
 /**
  * Helper macro to construct an enumeration wrapper Enum<E> for
  * a specific enum type.
@@ -276,13 +281,13 @@ public:
  * // declaration of enumeration; somewhere
  * class rfsv {
  * [...]
- * 	enum PSI_ERROR_CODES { E_PSI_GEN_NONE, E_PSI_GEN_FAIL, E_PSI_GEN_ARG };
+ *	enum PSI_ERROR_CODES { E_PSI_GEN_NONE, E_PSI_GEN_FAIL, E_PSI_GEN_ARG };
  * [...]
  * };
  *
  * // definition of the Enum<E> with the appropriate string representations
  * ENUM_DEFINITION(rfsv::PSI_ERROR_CODES,
- *	 	   rfsv::E_PSI_GEN_NONE) {
+ *		   rfsv::E_PSI_GEN_NONE) {
  *	stringRep.add(rfsv::E_PSI_GEN_NONE,	"no error");
  *	stringRep.add(rfsv::E_PSI_GEN_FAIL,	"general");
  *	stringRep.add(rfsv::E_PSI_GEN_ARG,	"bad argument");
@@ -295,17 +300,17 @@ public:
  *
  * @author Henner Zeller
  */
+/**								
+  * The definition of the static variable holding the static	
+  * data for this Enumeration wrapper.				
+  */								
 #define ENUM_DEFINITION(EnumName, initWith)			\
-/**								\
-  * The definition of the static variable holding the static	\
-  * data for this Enumeration wrapper.				\
-  */								\
-Enum<EnumName>::sdata Enum<EnumName>::staticData;		\
+template Enum< EnumName >::sdata Enum< EnumName >::staticData;	\
 /**								\
   * actual definition of the constructor for the static data.	\
   * This is called implicitly by the definition above.		\
   */								\
-Enum<EnumName>::sdata::sdata() :				\
+template <> Enum<EnumName>::sdata::sdata() :				\
 name(#EnumName),defaultValue(initWith)
 
 /**
