@@ -1,5 +1,5 @@
 /*-*-c++-*-
- * $Id: ppsocket.cc,v 1.21 2002/08/05 12:36:02 felfert Exp $
+ * $Id: ppsocket.cc,v 1.23 2004/09/08 17:09:06 thomasklausner Exp $
  *
  * This file is part of plptools.
  *
@@ -25,10 +25,15 @@
 #include "config.h"
 #endif
 
+#include "bufferstore.h"
+#include "ppsocket.h"
+#include "iowatch.h"
+
+#include <iostream>
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <stdarg.h>
-#include <iostream.h>
 #include <fcntl.h>
 #include <unistd.h>
 #include <errno.h>
@@ -38,13 +43,13 @@
 #include <netinet/in.h>
 #include <arpa/inet.h>
 
-#include "bufferstore.h"
-#include "ppsocket.h"
-#include "iowatch.h"
-
 #define  INVALID_SOCKET	-1
 #define  SOCKET_ERROR	-1
 
+#ifndef MSG_NOSIGNAL
+#define MSG_NOSIGNAL 0
+#endif
+
 using namespace std;
 
 ppsocket::ppsocket(const ppsocket & another)
