@@ -1,5 +1,5 @@
 /*-*-c++-*-
- * $Id: rfsv.cc,v 1.10 2002/07/17 13:39:49 basic Exp $
+ * $Id: rfsv.cc,v 1.11 2003/02/05 07:59:08 felfert Exp $
  *
  * This file is part of plptools.
  *
@@ -22,6 +22,10 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
  */
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "rfsv.h"
 #include "ppsocket.h"
 #include "bufferstore.h"
