@@ -1,5 +1,5 @@
 /*-*-c++-*-
- * $Id: rfsv16.cc,v 1.25 2002/07/14 06:35:33 felfert Exp $
+ * $Id: rfsv16.cc,v 1.26 2003/02/05 07:59:08 felfert Exp $
  *
  * This file is part of plptools.
  *
@@ -26,18 +26,17 @@
 #include "config.h"
 #endif
 
-#include <stream.h>
-#include <stdlib.h>
-#include <fstream.h>
-#include <iomanip>
-#include <time.h>
-#include <string>
-
 #include "rfsv16.h"
 #include "bufferstore.h"
 #include "ppsocket.h"
 #include "bufferarray.h"
 
+#include <iostream>
+#include <fstream>
+
+#include <stdlib.h>
+#include <time.h>
+
 #define	RFSV16_MAXDATALEN	852	// 640
 
 using namespace std;
@@ -347,7 +346,6 @@ devlist(u_int32_t &devbits)
 	return status;
 
     while (1) {
-	bufferStore a;
 	a.init();
 	a.addWord(fileHandle & 0xFFFF);
 	if (!sendCommand(FDEVICEREAD, a))
