@@ -1,5 +1,5 @@
 /*-*-c++-*-
- * $Id: rfsv32.cc,v 1.24 2002/07/14 06:35:33 felfert Exp $
+ * $Id: rfsv32.cc,v 1.25 2003/02/05 07:59:08 felfert Exp $
  *
  * This file is part of plptools.
  *
@@ -25,19 +25,18 @@
 #include "config.h"
 #endif
 
-#include <stream.h>
-#include <stdlib.h>
-#include <fstream>
-#include <iomanip>
-#include <time.h>
-#include <string>
-
 #include "rfsv32.h"
 #include "bufferstore.h"
 #include "ppsocket.h"
 #include "bufferarray.h"
 #include "plpdirent.h"
 
+#include <iostream>
+#include <fstream>
+
+#include <stdlib.h>
+#include <time.h>
+
 using namespace std;
 
 rfsv32::rfsv32(ppsocket * _skt)
@@ -856,14 +855,14 @@ static enum rfsv::errs e2psi[] = {
 };
 
 Enum<rfsv::errs> rfsv32::
-err2psierr(int32_t status)
+err2psierr(int32_t istatus)
 {
-    if ((status > E_EPOC_NONE) || (status < E_EPOC_DIR_FULL)) {
-	cerr << "FATAL: inavlid error-code" << endl;
-	cerr << "status: " << status << " " << hex << status << endl;
+    if ((istatus > E_EPOC_NONE) || (istatus < E_EPOC_DIR_FULL)) {
+	cerr << "FATAL: invalid error-code" << endl;
+	cerr << "status: " << istatus << " " << hex << istatus << endl;
 	return E_PSI_INTERNAL;
     }
-    return e2psi[status - E_EPOC_DIR_FULL];
+    return e2psi[istatus - E_EPOC_DIR_FULL];
 }
 
 
