@@ -1,5 +1,5 @@
 /*-*-c++-*-
- * $Id: rfsvfactory.cc,v 1.6 2002/07/14 06:35:33 felfert Exp $
+ * $Id: rfsvfactory.cc,v 1.7 2003/02/05 07:59:08 felfert Exp $
  *
  * This file is part of plptools.
  *
@@ -24,13 +24,6 @@
 #include "config.h"
 #endif
 
-#include <stream.h>
-#include <stdlib.h>
-#include <fstream.h>
-#include <iomanip.h>
-#include <time.h>
-#include <string.h>
-
 #include "rfsv.h"
 #include "rfsv16.h"
 #include "rfsv32.h"
@@ -39,6 +32,9 @@
 #include "ppsocket.h"
 #include "Enum.h"
 
+#include <stdlib.h>
+#include <time.h>
+
 using namespace std;
 
 ENUM_DEFINITION(rfsvfactory::errs, rfsvfactory::FACERR_NONE) {
