@@ -1,5 +1,5 @@
 /*-*-c++-*-
- * $Id: channel.cc,v 1.7 2002/03/16 23:10:51 felfert Exp $
+ * $Id: channel.cc,v 1.8 2003/02/05 07:59:09 felfert Exp $
  *
  * This file is part of plptools.
  *
@@ -24,7 +24,7 @@
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
-#include <stream.h>
+#include <iostream>
 #include <string>
 
 #include "channel.h"
