@@ -1,5 +1,5 @@
 /*-*-c++-*-
- * $Id: link.cc,v 1.21 2003/02/03 08:29:26 felfert Exp $
+ * $Id: link.cc,v 1.22 2003/02/05 07:59:09 felfert Exp $
  *
  * This file is part of plptools.
  *
@@ -25,18 +25,20 @@
 #include "config.h"
 #endif
 
-#include <stream.h>
+#include <iostream>
+
+#include <bufferstore.h>
+#include <bufferarray.h>
+#include <plp_inttypes.h>
+
 #include <stdlib.h>
 #include <unistd.h>
 #include <stdio.h>
 #include <sys/time.h>
-#include <plp_inttypes.h>
 
 #include "link.h"
 #include "packet.h"
 #include "ncp.h"
-#include "bufferstore.h"
-#include "bufferarray.h"
 #include "main.h"
 
 extern "C" {
