@@ -1,5 +1,5 @@
 /*-*-c++-*-
- * $Id: linkchan.cc,v 1.11 2002/07/16 00:06:30 felfert Exp $
+ * $Id: linkchan.cc,v 1.12 2003/02/05 07:59:09 felfert Exp $
  *
  * This file is part of plptools.
  *
@@ -21,14 +21,14 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
  */
-#include <stream.h>
 #include <iomanip>
 #include <string>
 
+#include <bufferstore.h>
+#include <bufferarray.h>
+
 #include "linkchan.h"
 #include "ncp.h"
-#include "bufferstore.h"
-#include "bufferarray.h"
 #include "main.h"
 
 using namespace std;
