@@ -1,5 +1,5 @@
 /* -*- Mode: C++ -*-
- * $Id: plpbackup.cc,v 1.14 2003/02/04 10:26:35 felfert Exp $
+ * $Id: plpbackup.cc,v 1.19 2004/10/04 16:04:26 rrt Exp $
  *
  * This file is part of plptools.
  *
@@ -25,15 +25,26 @@
 #include <config.h>
 #endif
 
-#include <sys/types.h>
-#include <sys/wait.h>
-#include <dirent.h>
 #include <fstream>
-#include <strstream>
+#include <sstream>
+#include <iostream>
 #include <iomanip>
 #include <vector>
 #include <set>
 
+#include <plpintl.h>
+#include <ppsocket.h>
+#include <rfsv.h>
+#include <rfsvfactory.h>
+#include <rpcs.h>
+#include <rpcsfactory.h>
+#include <bufferstore.h>
+#include <bufferarray.h>
+
+#include <sys/types.h>
+#include <sys/wait.h>
+#include <dirent.h>
+
 #include <ctype.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -46,22 +57,12 @@
 #include <getopt.h>
 #include <fcntl.h>
 
-#include <plpintl.h>
-#include <ppsocket.h>
-#include <rfsv.h>
-#include <rfsvfactory.h>
-#include <rpcs.h>
-#include <rpcsfactory.h>
-#include <bufferstore.h>
-#include <bufferarray.h>
-
 using namespace std;
 
 bool full = false;
 bool S5mx = false;
 bool doRestore = false;
 bool doBackup = false;
-bool doFormat = false;
 bool skipError = false;
 bool doAbort = false;
 bool overWriteAll = false;
@@ -287,21 +288,21 @@ startPrograms() {
 		// If we got an error here, that happened probably because
 		// we have no path at all (e.g. Macro5) and the program is
 		// not registered in the Psion's path properly. Now try
-		// the ususal \System\Apps\<AppName>\<AppName>.app
+		// the usual \System\Apps\<AppName>\<AppName>.app
 		// on all drives.
 		if (cmd.find('\\') == cmd.npos) {
 		    u_int32_t devbits;
 		    if ((res = Rfsv->devlist(devbits)) == rfsv::E_PSI_GEN_NONE) {
 			int i;
 			for (i = 0; i < 26; i++) {
-			    if (devbits & 1) {
-				ostrstream tmp;
-				tmp << 'A' + i << "\\System\\Apps\\"
-				    << cmd << "\\" << cmd << ".app";
-				res = Rpcs->execProgram(tmp.str(), "");
+			    if (devbits & (1 << i)) {
+				ostringstream tmp;
+				tmp << (char)('A' + i) << ":\\System\\Apps\\" <<
+                                  cmd << "\\" << cmd << ".app" << '\0';
+				res = Rpcs->execProgram(tmp.str().c_str(), "");
+                                if (res == rfsv::E_PSI_GEN_NONE)
+                                    break;
 			    }
-			    if (res == rfsv::E_PSI_GEN_NONE)
-				break;
 			}
 		    }
 		}
@@ -485,13 +486,9 @@ startMessage(const char *arch)
 {
     if (verbose >= 0) {
 	cout << _("Performing ");
-	if (doFormat)
-	    cout << _("format");
-	if (doRestore) {
-	    if (doFormat)
-		cout << _(" and ");
+	if (doRestore)
 	    cout << _("restore");
-	} else
+	else
 	    cout << (full ? _("full") : _("incremental")) << _(" backup");
 	cout << _(" of ");
 	if (driveList.empty())
@@ -529,12 +526,6 @@ tdiff(struct timeval *start, struct timeval *end)
     return (e - s) / 1000000.0;
 }
 
-static int
-runFormat()
-{
-    return 0;
-}
-
 static int
 editfile(char *name)
 {
@@ -867,7 +858,7 @@ runRestore()
 {
     unsigned int i;
     char indexbuf[40];
-    ostrstream tarcmd;
+    ostringstream tarcmd;
     string dstPath;
     struct timeval start_tv, end_tv, cstart_tv, cend_tv;
 
@@ -875,7 +866,7 @@ runRestore()
 	tarcmd << "tar --to-stdout -xzf " << archList[i]
 	       << " 'KPsion*Index'" << ends;
 	char backupType = '?';
-	FILE *f = popen(tarcmd.str(), "r");
+	FILE *f = popen(tarcmd.str().c_str(), "r");
 	if (!f) {
 	    perror(_("Could not get backup index"));
 	    continue;
@@ -932,7 +923,7 @@ runRestore()
 		tarcmd << "tar xzCf " << dstPath << " " << fn << ends;
 		if (verbose > 0)
 		    cout << _("Extracting tar archive ...") << endl;
-		if (system(tarcmd.str()) != 0)
+		if (system(tarcmd.str().c_str()) != 0)
 		    cerr << _("Execution of ") << tarcmd.str() << _(" failed.")
 			 << endl;
 		continue;
@@ -997,7 +988,7 @@ runRestore()
 		u_int32_t sattr = e.getAttr() & mask;
 		u_int32_t dattr = ~sattr & mask;
 		int retry = 10;
-		// Retry, because file somtimes takes some time
+		// Retry, because file sometimes takes some time
 		// to close;
 		do {
 		    res = Rfsv->fsetattr(fn, sattr, dattr);
@@ -1340,7 +1331,7 @@ runBackup()
 
 	// tar it all up
 	if (!bErr) {
-	    ostrstream tarcmd;
+	    ostringstream tarcmd;
 
 	    if (verbose > 0)
 		cout << _("Creating tar archive ...") << endl;
@@ -1355,7 +1346,7 @@ runBackup()
 	    tarcmd << ends;
 
 	    mkdirp(archPath.c_str());
-	    if (system(tarcmd.str())) {
+	    if (system(tarcmd.str().c_str())) {
 		cerr << _("plpbackup: Error during execution of ")
 		     << tarcmd.str() << endl;
 		unlink(archPath.c_str());
@@ -1420,7 +1411,6 @@ usage(ostream *hlp)
 	      "    -f, --full             Do a full backup (incremental otherwise).\n"
 	      "    -b, --backup[=TGZ]     Backup to specified archive TGZ.\n"
 	      "    -r, --restore=TGZ      Restore from specified archive TGZ.\n"
-	      "    -F, --format           Format drive (can be combined with restore).\n"
 	      "\n"
 	      "  <drive> A drive character. If none given, scan all drives.\n"
 	      "\n");
@@ -1439,7 +1429,6 @@ static struct option opts[] = {
     { "quiet",   no_argument,       0, 'q' },
     { "backup",  optional_argument, 0, 'b' },
     { "restore", required_argument, 0, 'r' },
-    { "format",  no_argument,       0, 'F' },
     { "version", no_argument,       0, 'V' },
     { 0,         0,                 0, 0   },
 };
@@ -1520,9 +1509,6 @@ main(int argc, char **argv)
 		doRestore = true;
 		archList.push_back(optarg);
 		break;
-	    case 'F':
-		doFormat = true;
-		break;
 	    case 'p':
 		parse_destination(optarg, &host, &sockNum);
 		break;
@@ -1540,19 +1526,19 @@ main(int argc, char **argv)
 	}
 	driveList.push_back(argv[i]);
     }
-    if (doBackup && (doRestore || doFormat)) {
-	cerr << _("Backup mode can not be combined with format or restore.")
+    if (doBackup && doRestore) {
+	cerr << _("Backup mode can not be combined with restore.")
 	     << endl;
 	usage(&cerr);
     }
-    if (doFormat && driveList.empty()) {
-	cerr << _("Format mode needs at least one drive specified.") << endl;
-	usage(&cerr);
-    }
     if (doBackup && (archList.size() > 1)) {
 	cerr << _("Backup can only create one archive at a time.") << endl;
 	usage(&cerr);
     }
+    if (!(doBackup || doRestore)) {
+	cerr << _("No action specified.") << endl;
+	usage(&cerr);
+    }
 
     signal(SIGTERM, sig_handler);
     signal(SIGINT, sig_handler);
@@ -1596,8 +1582,6 @@ main(int argc, char **argv)
 	runBackup();
     if (doRestore)
 	runRestore();
-    if (doFormat)
-	runFormat();
     delete Rpcs;
     delete Rfsv;
     return 0;
