@@ -1,5 +1,5 @@
 /*-*-c++-*-
- * $Id: main.cc,v 1.18 2002/07/14 19:07:06 felfert Exp $
+ * $Id: main.cc,v 1.19 2003/02/05 07:59:09 felfert Exp $
  *
  * This file is part of plptools.
  *
@@ -25,11 +25,6 @@
 #include <config.h>
 #endif
 
-#include <stream.h>
-#include <string.h>
-#include <stdlib.h>
-#include <stdio.h>
-
 #include <plpintl.h>
 #include <ppsocket.h>
 #include <rfsv.h>
@@ -38,6 +33,12 @@
 #include <rpcsfactory.h>
 #include <bufferstore.h>
 
+#include <iostream>
+#include <string>
+
+#include <stdlib.h>
+#include <stdio.h>
+
 #include "ftp.h"
 
 #ifndef _GNU_SOURCE
@@ -45,6 +46,8 @@
 #endif
 #include <getopt.h>
 
+using namespace std;
+
 static void
 help()
 {
