@@ -1,5 +1,5 @@
 /*-*-c++-*-
- * $Id: main.cc,v 1.25 2002/07/14 19:07:06 felfert Exp $
+ * $Id: main.cc,v 1.26 2003/02/05 07:59:09 felfert Exp $
  *
  * This file is part of plptools.
  *
@@ -24,29 +24,31 @@
 #include <config.h>
 #endif
 
-#include <stream.h>
-#include <string.h>
+#include <rfsv.h>
+#include <rpcs.h>
+#include <rfsvfactory.h>
+#include <rpcsfactory.h>
+#include <bufferstore.h>
+#include <bufferarray.h>
+#include <ppsocket.h>
+
+#include <iostream>
+#include <string>
+
 #include <stdlib.h>
 #include <stdio.h>
 #include <signal.h>
 #include <syslog.h>
 
-#include "rfsv.h"
-#include "rpcs.h"
-#include "rfsvfactory.h"
-#include "rpcsfactory.h"
-#include "bufferstore.h"
-#include "bufferarray.h"
-#include "ppsocket.h"
-extern "C" {
 #include "rfsv_api.h"
-}
 
 #ifndef _GNU_SOURCE
 #define _GNU_SOURCE
 #endif
 #include <getopt.h>
 
+using namespace std;
+
 static rfsv *a;
 static rfsvfactory *rf;
 static char *a_filename = 0;
