@@ -1,4 +1,4 @@
-/* $Id: mp_main.c,v 1.10 2003/01/31 22:52:47 felfert Exp $
+/* $Id: mp_main.c,v 1.11 2004/09/08 16:46:04 thomasklausner Exp $
  *
  * Original version of this file from p3nfsd-5.4 by
  * Rudolf Koenig (rfkoenig@immd4.informatik.uni-erlangen.de)
@@ -22,7 +22,7 @@
 #include <errno.h>
 #include "nfs_prot.h"
 #include "mp.h"
-#if defined (__SVR4) || defined(__sgi)
+#if defined (__SVR4) || defined(__sgi) || defined(__NetBSD__)
 #include <stdlib.h>		/* getenv */
 #include <string.h>		/* strcmp */
 #endif
