@@ -1,5 +1,5 @@
 /*-*-c++-*-
- * $Id: plpprintd.cc,v 1.13 2003/02/03 00:56:52 felfert Exp $
+ * $Id: plpprintd.cc,v 1.14 2003/02/05 07:59:09 felfert Exp $
  *
  * This file is part of plptools.
  *
@@ -24,8 +24,13 @@
 #include <config.h>
 #endif
 
-#include <stream.h>
-#include <string.h>
+#include <ppsocket.h>
+#include <wprt.h>
+#include <psibitmap.h>
+
+#include <iostream>
+#include <string>
+
 #include <stdlib.h>
 #include <stdarg.h>
 #include <stdio.h>
@@ -35,10 +40,6 @@
 #include <sys/stat.h>
 #include <fcntl.h>
 
-#include <ppsocket.h>
-#include <wprt.h>
-#include <psibitmap.h>
-
 #ifndef _GNU_SOURCE
 #define _GNU_SOURCE
 #endif
